@@ -1,4 +1,4 @@
-package Dist::Zilla::Chrome::Term 6.002; # TRIAL
+package Dist::Zilla::Chrome::Term 6.003; # TRIAL
 # ABSTRACT: chrome used for terminal-based interaction
 
 use Moose;
@@ -21,7 +21,8 @@ has logger => (
   isa => 'Log::Dispatchouli',
   init_arg => undef,
   writer   => '_set_logger',
-  lazy_build => 1,
+  lazy => 1,
+  builder => '_build_logger',
 );
 
 sub _build_logger {
@@ -152,7 +153,7 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 6.002
+version 6.003
 
 =head1 OVERVIEW
 
