@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::PkgDist 6.002; # TRIAL
+package Dist::Zilla::Plugin::PkgDist 6.003; # TRIAL
 # ABSTRACT: add a $DIST to your packages
 
 use Moose;
@@ -101,7 +101,7 @@ sub munge_perl {
   }
 
   # the document is no longer correct; it must be reparsed before it can be used again
-  $file->encoded_content($document->serialize);
+  $file->content($document->serialize);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -119,7 +119,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 6.002
+version 6.003
 
 =head1 DESCRIPTION
 
