@@ -1,4 +1,4 @@
-package Dist::Zilla::Tester 6.002; # TRIAL
+package Dist::Zilla::Tester 6.003; # TRIAL
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
 use Moose;
@@ -112,7 +112,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Builder 6.002; # TRIAL
+  package Dist::Zilla::Tester::_Builder 6.003; # TRIAL
 
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -140,8 +140,8 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
     mkdir $tempdir_root if defined $tempdir_root and not -d $tempdir_root;
 
     my $tempdir_obj = File::Temp->newdir(
-        CLEANUP => 1,
-        (defined $tempdir_root ? (DIR => $tempdir_root) : ()),
+      CLEANUP => 1,
+      (defined $tempdir_root ? (DIR => $tempdir_root) : ()),
     );
 
     my $tempdir = path( path($tempdir_obj)->absolute) ;
@@ -172,7 +172,22 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
     $Log_Events = $arg->{chrome}->logger->events;
 
-    local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
+    local @INC = @INC;
+
+    my $had_dot;
+    if ($INC[-1] eq '.') {
+      $had_dot = 1;
+      pop @INC;
+    }
+
+    @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
+
+    push @INC, '.' if $had_dot;
+
+    # We do this so that . in @INC will find plugins like [=inc::YourFace]
+    # -- rjbs, 2016-04-24
+    my $wd = File::pushd::pushd($arg->{dist_root});
+
 
     local $ENV{DZIL_GLOBAL_CONFIG_ROOT};
     $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $tester_arg->{global_config_root}
@@ -235,7 +250,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Minter 6.002; # TRIAL
+  package Dist::Zilla::Tester::_Minter 6.003; # TRIAL
 
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -340,7 +355,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 6.002
+version 6.003
 
 =head1 AUTHOR
 
